@@ -5,6 +5,13 @@ import sys
 import inspect
 import json
 
+from concurrent import futures
+import grpc
+from cakework import cakework_pb2
+from cakework import cakework_pb2_grpc
+from .activity_server import ActivityServer
+import importlib
+
 # TODO: trim this requirements.txt file and remove extraneous stuff
 # need to copy over the requirements.txt?
 # grpciotools - only needed for compiling the protobuf files. don't need to package this with the pypi distribution
@@ -14,10 +21,11 @@ class App:
 	# do we actually need the url? 
 	# TODO figure out how to allow people to specify the version of python to use
 	# TODO infer user id automatically
-	def __init__(self, app, user_id="shared"):
+	def __init__(self, app, user_id="shared"): # TODO change app to name
 		# TODO sanitize the user id and app name
 		self.user_id = user_id # TODO once we have auth will no longer have this be shared
 		self.app = app
+
 		# create a build directory 
 		self.current_dir = os.getcwd()
 		self.build_dir = self.current_dir
@@ -38,27 +46,32 @@ class App:
 		# 	print("will copy file: " + f_copy)
 		# 	self.files_to_copy.append(f_copy)
 
-
 	# create a new sub-directory in the build directory with the activity_name
 	# copy protobuf files over
 	# copy the cakework_server file over and modify it
 
-	def register_activity(self, activity, activity_name):
+	def register_activity(self, activity):
 		print("Registering activity")
+		activity_server = ActivityServer(activity) # Q: this gets shut down?
+		activity_server.start()
+		# start the activity server
+
+
+
 		# inspect the activity to get the module
-		self.config['module'] = inspect.getmodule(activity).__name__
-		self.config['activity'] = activity_name # currently only supports one activity at a time
-		# verify that we wrote to the right place
-		print("registered module: " + self.config['module'] + " and activity: " + self.config['activity'])
+		# self.config['module'] = inspect.getmodule(activity).__name__
+		# self.config['activity'] = activity_name # currently only supports one activity at a time
+		# # verify that we wrote to the right place
+		# print("registered module: " + self.config['module'] + " and activity: " + self.config['activity'])
 
-		# activity_build_dir = os.path.join(self.build_dir, activity_name)
-		# print("activity build directory: ")
+		# # activity_build_dir = os.path.join(self.build_dir, activity_name)
+		# # print("activity build directory: ")
 
-		config_path = os.path.join(self.build_dir, 'cakework.json')
-		with open(config_path, 'w') as outfile:
-			outfile.write(json.dumps(self.config, indent=4))
+		# config_path = os.path.join(self.build_dir, 'cakework.json')
+		# with open(config_path, 'w') as outfile:
+		# 	outfile.write(json.dumps(self.config, indent=4))
 		
-		return config_path
+		# return config_path
 
 		# # copy entire current directory containing the script to a new build directory
 		# print("activity build directory: " + activity_build_dir)
@@ -132,3 +145,12 @@ class App:
 		# # # TODO also need to make sure the user's app.py file doesn't overwrite the cakework one
 		# # # TODO copy the user's requirements.txt file
 		# # # sanitize the activity name		
+		
+def serve():
+    port = '50051'
+    server = grpc.server(futures.ThreadPoolExecutor(max_workers=1)) # what should the default be?
+    cakework_pb2_grpc.add_CakeworkServicer_to_server(Cakework(), server)
+    server.add_insecure_port('[::]:' + port)
+    server.start()
+    print("Server started, listening on " + port)
+    server.wait_for_termination()
\ No newline at end of file
